Search.setIndex({"alltitles":{"Command-Line Tools":[[0,null]],"Description":[[1,"description"]],"FAQ":[[1,"faq"]],"Index and Search":[[0,"index-and-search"]],"Options":[[1,"options"]],"Output Format Versions":[[1,"output-format-versions"]],"Preprocessing":[[1,"preprocessing"]],"Schema":[[1,"schema"]],"Synopsis":[[1,"synopsis"]],"Why are C++ function bodies not dumped in XML?":[[1,"why-are-c-function-bodies-not-dumped-in-xml"]],"Why don\u2019t I see templates in the output?":[[1,"why-don-t-i-see-templates-in-the-output"]],"With --castxml-gccxml":[[1,"with-castxml-gccxml"]],"With --castxml-output=<v>":[[1,"with-castxml-output-v"]],"castxml(1)":[[1,null]]},"docnames":["index","manual/castxml.1"],"envversion":{"sphinx":65,"sphinx.domains.c":3,"sphinx.domains.changeset":1,"sphinx.domains.citation":1,"sphinx.domains.cpp":9,"sphinx.domains.index":1,"sphinx.domains.javascript":3,"sphinx.domains.math":2,"sphinx.domains.python":4,"sphinx.domains.rst":2,"sphinx.domains.std":2},"filenames":["index.rst","manual/castxml.1.rst"],"indexentries":{},"objects":{},"objnames":{},"objtypes":{},"terms":{"":1,"0":1,"1":0,"11":1,"139":1,"14":1,"20000000":1,"4":1,"9":1,"98":1,"At":1,"For":1,"If":1,"In":1,"It":1,"The":1,"__castxml__":1,"__castxml_check":1,"__castxml_clang_major__":1,"__castxml_clang_minor__":1,"__castxml_clang_patchlevel__":1,"__castxml_major__":1,"__castxml_minor__":1,"__castxml_patch__":1,"__clang_major__":1,"__clang_minor__":1,"__clang_patchlevel__":1,"abstract":1,"actual":1,"ad":1,"add":1,"affect":1,"alwai":1,"an":1,"arbitrari":1,"argument":1,"assign":1,"ast":1,"attribut":1,"avail":1,"backward":1,"becaus":1,"been":1,"between":1,"bin":1,"both":1,"bug":1,"c11":1,"c89":1,"c99":1,"candid":1,"case":1,"castxml":0,"cc":1,"ccyymmdd":1,"chang":1,"cl":1,"clang":1,"class":1,"client":1,"close":1,"collect":1,"comma":1,"command":1,"comparison":1,"compat":1,"compil":1,"complet":1,"compon":1,"configur":1,"constant":1,"construct":1,"constructor":1,"contain":1,"correspond":1,"current":1,"cvs_revis":1,"date":1,"decim":1,"declar":1,"default":1,"defin":1,"describ":1,"detect":1,"develop":1,"do":1,"doe":1,"drive":1,"e":1,"each":1,"either":1,"element":1,"enabl":1,"encod":1,"epic":1,"even":1,"ever":1,"exampl":1,"exist":1,"explicitli":1,"express":1,"famili":1,"featur":1,"file":1,"first":1,"fix":1,"flag":1,"follow":1,"foo":1,"foo_int":1,"form":1,"from":1,"g":1,"gcc":1,"gcc_xml":1,"gener":1,"given":1,"gnu":1,"ha":1,"had":1,"help":1,"howev":1,"id":1,"identifi":1,"implement":1,"implicit":1,"includ":1,"increment":1,"info":1,"inform":1,"input":1,"instanti":1,"int":1,"intern":1,"interpret":1,"its":1,"languag":1,"last":1,"less":1,"level":1,"line":1,"link":1,"list":1,"m32":1,"macro":1,"mai":1,"major":1,"match":1,"microsoft":1,"minor":1,"mode":1,"most":1,"move":1,"msvc":1,"multipl":1,"must":1,"n":1,"name":1,"need":1,"new":1,"non":1,"number":1,"o":1,"one":1,"oper":1,"opt":1,"other":1,"overridden":1,"own":1,"page":0,"pars":1,"particular":1,"patch":1,"place":1,"platform":1,"predefin":1,"preprocessor":1,"print":1,"project":1,"proper":1,"qualifi":1,"rc":1,"refer":1,"releas":1,"remain":1,"repeat":1,"repres":1,"represent":1,"root":1,"run":1,"second":1,"separ":1,"set":1,"should":1,"sinc":1,"sourc":1,"specifi":1,"src":1,"standard":1,"start":1,"std":1,"still":1,"struct":1,"subset":1,"support":1,"switch":1,"syntax":1,"tag":1,"target":1,"text":1,"than":1,"thei":1,"them":1,"thi":1,"third":1,"those":1,"though":1,"three":1,"togeth":1,"too":1,"tool":1,"translat":1,"travers":1,"tree":1,"type":1,"typedef":1,"unchang":1,"unimpl":1,"uninstanti":1,"unit":1,"unless":1,"unspecifi":1,"updat":1,"us":1,"usag":1,"usr":1,"valu":1,"via":1,"visual":1,"wa":1,"wai":1,"want":1,"when":1,"whenev":1,"where":1,"which":1,"work":1,"write":1,"written":1,"xsd":1},"titles":["CastXML Documentation","castxml(1)"],"titleterms":{"1":1,"With":1,"ar":1,"bodi":1,"c":1,"castxml":1,"command":0,"descript":1,"don":1,"dump":1,"faq":1,"format":1,"function":1,"gccxml":1,"i":1,"index":0,"line":0,"option":1,"output":1,"preprocess":1,"schema":1,"search":0,"see":1,"synopsi":1,"t":1,"templat":1,"tool":0,"v":1,"version":1,"why":1,"xml":1}})